{% extends 'virtenviro/admin/base.html' %}

{% block content %}
    <div class="row">
        <h1>Страницы</h1>
        <table class="table table-hover">
            <tbody>
            {% for page in pages %}
                <tr><td><a href="{% url 'vadmin:content_page_edit' page.pk %}">{{ page.title }}</a></td></tr>
            {% endfor %}
            </tbody>
        </table>
    </div>
    <div class="row">
        <nav>
            <ul class="pagination">
                {% if pages.has_previous %}
                <li>
                    <a href="?page={{ pages.previous_page_number }}" aria-label="Previous">
                        <span aria-hidden="true">&laquo;</span>
                    </a>
                </li>
                {% endif %}
                {% for page in pages.paginator.page_range %}
                    <li{% if page = pages.number %} class="active"{% endif %}><a href="?page={{ page }}">{{ page }}</a></li>
                {% endfor %}
                {% if contacts.has_next %}
                <li>
                    <a href="?page={{ contacts.next_page_number }}" aria-label="Next">
                        <span aria-hidden="true">&raquo;</span>
                    </a>
                </li>
                {% endif %}
            </ul>
        </nav>
    </div>
<!-- /.row -->
{% endblock content %}