<!DOCTYPE html>
<html>
<head lang="en">
    <meta charset="UTF-8">
</head>
<body>
<h2>Здравствуйте!</h2>

<p>Ваш email {{ profile.user.email }} был зарегистрирован на сайте {{ site.domain }}.<br>
Для активации профиля Вам необходимо пройти
    <a href="http://{{ site.domain }}/accounts/activate/{{ profile.user.pk }}/{{ profile.activation_code }}/">по ссылке</a>
</p>

<p>Если Вы не регистрировались на сайте {{ site.domain }}, просим удалить это письмо.</p>
<p>В этом случае процесс активации профиля будет остановлен.</p>
</body>
</html>