CKEDITOR.plugins.setLang('syntaxhighlight', 'fr', {
	title:'Ajouter ou modifier un morceau de code source',
	contextTitle:'&Eacute;diter le code source',
	sourceTab:'Code source',
	langLbl:'Sélectionnez le langage:',
	sourceTextareaEmptyError:'Le code source ne doit pas être vide',
	advancedTab:'Avancé',
	hideGutter:'Cacher la marge',
	hideGutterLbl:'Cacher la marge et les numéros de ligne.',
	hideControls:'Cacher la barre d\'outils',
	hideControlsLbl:'Cacher la barre d\'outils en haut du bloc de code.',
	collapse:'Réduire le code',
	collapseLbl:'Réduire le bloc de code par défaut. (la barre d\'outils doit être activée)',
	codeTitleLbl:'Employez un titre de code',
	showColumns:'Montrer les colonnes',
	showColumnsLbl:'Montrer les colonnes sur la première ligne.',
	lineWrap:'Désactiver le retour à la ligne automatique',
	lineWrapLbl:'Désactiver le retour à la ligne automatique (ne fonctionne plus avec SyntaxHighlighter 3).',
	lineCount:'Numéro de la première ligne (différent de 1)',
	highlight:'Surligner les lignes',
	highlightLbl:'Entrez les numéros des lignes que vous souhaitez surligner, séparés par des virgules. ex <em style="font-style:italic">3,10,15</em>.'
});