{% extends 'virtenviro/../../admin/base.html' %}

{% block form %}
    <form action="" method="post" enctype="multipart/form-data">{% csrf_token %}
    {{ form.as_p }}
    <input type="submit" value="Save">
    </form>
{% endblock form %}