{% load staticfiles %}
<!-- jQuery -->
<script src="https://yastatic.net/jquery/2.1.4/jquery.min.js"></script>
<!-- Bootstrap Core JavaScript -->
<script src="{% static 'vadmin/js/bootstrap.min.js' %}"></script>