CKEDITOR.plugins.setLang('syntaxhighlight', 'en', {
	title:'Add or update a code snippet',
	contextTitle:'Edit source code',
	sourceTab:'Source code',
	langLbl:'Select language',
	sourceTextareaEmptyError:'Source code mustn\'t be empty.',
	advancedTab:'Advanced',
	hideGutter:'Hide gutter',
	hideGutterLbl:'Hide gutter & line numbers.',
	hideControls:'Hide controls',
	hideControlsLbl:'Hide code controls at the top of the code block.',
	collapse:'Collapse',
	collapseLbl:'Collapse the code block by default. (controls need to be turned on)',
	codeTitleLbl:'Use a Code Title',
	showColumns:'Show columns',
	showColumnsLbl:'Show row columns in the first line.',
	lineWrap:'Disable line wrapping',
	lineWrapLbl:'Switch off line wrapping.',
	lineCount:'Default line count',
	highlight:'Highlight lines',
	highlightLbl:'Enter a comma seperated lines of lines you want to highlight, eg <em style="font-style:italic">3,10,15</em>.'
});