CKEDITOR.plugins.setLang( 'syntaxhighlight', 'zh-cn', {
	title:'插入代码',
	contextTitle:'编辑源代码',
	sourceTab:'源代码',
	langLbl:'选择语言',
	sourceTextareaEmptyError:'源代码不能为空!',
	advancedTab:'高级',
	hideGutter:'隐藏栏距',
	hideGutterLbl:'隐藏左侧的栏距和行号',
	hideControls:'隐藏控件',
	hideControlsLbl:'隐藏代码块顶端的所有控件',
	collapse:'折叠',
	collapseLbl:'初始化时折叠代码块',
	codeTitleLbl:'添加代码片段标题',
	showColumns:'显示列',
	showColumnsLbl:'在首行显示行列',
	lineWrap:'禁用自动换行',
	lineWrapLbl:'关闭自动换行',
	lineCount:'自定义起始行号',
	highlight:'自定义高亮行号(用于强调某些行)',
	highlightLbl:'用逗号分隔需要高亮显示的行号, 例如<em style="font-style:italic">3,10,15</em>.'
});
