CKEDITOR.plugins.setLang('syntaxhighlight', 'de', {
	title:'Einen Quelltextabschnitt einfügen oder aktualisieren',
	contextTitle:'Quelltext bearbeiten',
	sourceTab:'Quelltext',
	langLbl:'Sprache auswählen',
	sourceTextareaEmptyError:'Das Quelltext-Feld darf nicht leer sein.',
	advancedTab:'Erweitert',
	hideGutter:'Verstecke Seitenleiste',
	hideGutterLbl:'Verstecke Seitenleiste und Zeilennummern.',
	hideControls:'Verstecke Kontrollfelder',
	hideControlsLbl:'Verstecke die Menüleiste über dem Quelltextblock.',
	collapse:'Einklappen',
	collapseLbl:'Klappe den Quelltextblock standartmäßig ein. (Kontrollfelder müssen aktiviert werden)',
	codeTitleLbl:'Einen Code-Titel verwenden',
	showColumns:'Spalten anzeigen',
	showColumnsLbl:'Zeige Spalten jeder Zeile in der Kopfzeile an.',
	lineWrap:'Zeilenumbruch',
	lineWrapLbl:'Deaktiviere Zeilenumbrüche.',
	lineCount:'Nummerierung der ersten Zeile (falls ungleich 1)',
	highlight:'Zeilen hervorheben',
	highlightLbl:'Geben Sie kommasepariert die Zeilen ein, die sie hervorheben wollen, z.B. <em style="font-style:italic">3,10,15</em>.'
});