{% extends 'virtenviro/admin/base.html' %}{% load i18n %}

{% block page_header %}{% endblock %}

{% block content %}
    <form class="form" action="" method="post" enctype="multipart/form-data">
    {% csrf_token %}
    <div class="form-group">
        <label for="xml_file_id">YML {% trans 'file' %}</label>
        <input type="file" class="" name="xml_file" id="id_xml_file" required="required">
    </div>
    <button class="btn btn-primary">{% trans 'Save' %}</button>
    </form>
{% endblock content %}

{% block extrascripts %}{% endblock %}