<!DOCTYPE html>
<html>
<head lang="en">
    <meta charset="UTF-8">
</head>
<body>
<h2>Уважаемый пользователь сайта {{ site.domain }}!</h2>

<p>По Вашему запросу запущен процесс восстановления пароли.</p>
<p>Чтобы продолжить, необходимо перейти по ссылке
    <a href="http://{{ site.domain }}/accounts/repair/{{ profile.user.pk }}/{{ profile.activation_code }}/">восстановления пароли</a>.
</p>
<p>Иначе просим удалить это письмо. В этом случае процесс восстановления пароли будет остановлен.</p>
</body>
</html>