{% load mptt_tags i18n %}
    <li><h4>{% trans 'Pages' %} <a href="{% url 'vadmin:content_page_add' %}"><span class="fa fa-plus"></span></a></h4></li>
{% recursetree nodes %}
    <li{% if node == current_page %} class="active"{% endif %}>
        <a {% if node == current_page %}href="javascript:;"  {% else %}href="/vadmin/content/{{ node.pk }}/"{% endif %}>{{ node.title }}</a>
        {% if not node.is_leaf_node and not node.parent == current_page %}
        <ul class="children">
            {{ children }}
        </ul>
        {% endif %}
    </li>
{% endrecursetree %}