<!DOCTYPE html>{% load staticfiles %}{% load vtags %}
<html>
<head>
    <meta charset="utf-8">
    <meta http-equiv="X-UA-Compatible" content="IE=edge">
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <meta name="description" content="">
    <meta name="author" content="">
    <title>{% block meta_title %}{% endblock meta_title %}Virtenviro Admin</title>
    <link href="{% static 'vadmin/css/styles.css' %}" rel="stylesheet">
    <link href="{% static 'css/font-awesome.min.css' %}" rel="stylesheet">
    <!-- HTML5 Shim and Respond.js IE8 support of HTML5 elements and media queries -->
    <!-- WARNING: Respond.js doesn't work if you view the page via file:// -->
    <!--[if lt IE 9]>
        <script src="https://oss.maxcdn.com/libs/html5shiv/3.7.0/html5shiv.js"></script>
        <script src="https://oss.maxcdn.com/libs/respond.js/1.4.2/respond.min.js"></script>
    <![endif]-->

    {% include 'virtenviro/admin/elements/scripts.html' %}
    {% block extrascripts %}{% endblock %}
</head>
<body>
{% include 'virtenviro/admin/navbar.html' %}
<div class="container">
    <div class="col-md-4">{% block navigation %}{% include 'virtenviro/admin/navigation.html' %}{% endblock %}</div>
    <div class="col-md-8">{% block content %}{% endblock %}</div>
</div>
<footer class="container"></footer>
</body>
</html>