// Import Bootstrap Compass integration
@import "bootstrap-compass";

// Import Bootstrap for Sass
@import "bootstrap";

body {
  padding: 70px 0;
}

label {
  font-weight: 400;

  &.required {
    font-weight: bold;

    &:after {
      content: "*";
    }
  }
  &.excepted {
    color: red;
  }
}

.buttons-panel {
  position: fixed;
  bottom: 0;
  left: 0;
  padding: 15px 0;
  width: 100%;
  background-color: #1b6d85;
}

@import "navigation";