{% load i18n %}
<nav class="navbar navbar-inverse navbar-fixed-top">
    <div class="container">
        <!-- Brand and toggle get grouped for better mobile display -->
        <div class="navbar-header">
            <button type="button" class="navbar-toggle collapsed" data-toggle="collapse" data-target="#bs-example-navbar-collapse-1" aria-expanded="false">
                <span class="sr-only">Toggle navigation</span>
                <span class="icon-bar"></span>
                <span class="icon-bar"></span>
                <span class="icon-bar"></span>
            </button>
            <a class="navbar-brand" href="{% url 'vadmin:home' %}">Virtenviro</a>
        </div>

        <!-- Collect the nav links, forms, and other content for toggling -->
        <div class="collapse navbar-collapse" id="bs-example-navbar-collapse-1">
            <ul class="nav navbar-nav">
                <li class="dropdown">
                    <a href="#" class="dropdown-toggle" data-toggle="dropdown" role="button" aria-haspopup="true" aria-expanded="false">{% trans 'Content' %} <span class="caret"></span></a>
                    <ul class="dropdown-menu">
                        <li><a href="{% url 'vadmin:content' %}">{% trans 'Pages' %}</a></li>
                        <li><a href="#">{% trans 'Templates' %}</a></li>
                        <li><a href="#">{% trans 'Menus' %}</a></li>
                        <li><a href="#">{% trans 'Snippets' %}</a></li>
                        <li><a href="#">{% trans 'Tags' %}</a></li>
                        <li><a href="#">{% trans 'Additional fields' %}</a></li>
                    </ul>
                </li>
            </ul>
            <form class="navbar-form navbar-left" role="search">
                <div class="form-group">
                    <input type="text" class="form-control" placeholder="Search">
                </div>
                <button type="submit" class="btn btn-default">Submit</button>
            </form>
            <ul class="nav navbar-nav navbar-right">
                <li class="dropdown">
                    <a href="#" class="dropdown-toggle" data-toggle="dropdown" role="button" aria-haspopup="true" aria-expanded="false">{{ user.username }} <span class="caret"></span></a>
                    <ul class="dropdown-menu">
                        <li><a href="#">{% trans 'Profile' %}</a></li>
                        <li role="separator" class="divider"></li>
                        <li><a href="{% url 'admin:logout' %}">{% trans 'Logout' %}</a></li>
                    </ul>
                </li>
            </ul>
        </div><!-- /.navbar-collapse -->
    </div><!-- /.container-fluid -->
</nav>